<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8"/>
    <meta http-equiv="X-UA-Compatible" content="IE=edge"/>
    <meta name="viewport" content="width=device-width, initial-scale=1"/>
    <title>{{ title|striptags|e }}{{ titlesuffix }}</title>
    {% if siteconfig.favicon %}
        <link rel="icon"
              href="{{ pathto('_static/' + siteconfig.favicon, 1) }}"/>
    {% endif %}
    <link href="https://use.fontawesome.com/releases/v5.0.6/css/all.css"
          rel="stylesheet">
    <script src="{{ pathto('_static/kaybee_bulma.bundle.js', 1) }}"></script>
    <script src="{{ pathto('_static/app.bundle.js', 1) }}"></script>
</head>
<body>
{% set style = resource.acquire(resources, 'style') if resource else None %}
<section>
    {% include "navbar.html" %}
</section>
<section
        class="hero {{ 'is-' + style if style else '' }}"
        style="{% block hero_image %}{% endblock %}">
    <div class="hero-head">
    </div>
    {% block hero %}{% endblock %}
</section>

<section class="section content {{ resource.rtype if resource }}"
         id="kbb-sphinx-body">
    {% block body %}{% endblock %}
</section>

{% include "footer.html" %}
{% include "document_settings.html" %}

</body>
</html>

