// Include Sphinx and Pygments CSS into the bundle
@import "../static/basic.css";
@import "../static/pygments.css";

@import "../../node_modules/bulma/sass/utilities/initial-variables";
@import "../../node_modules/bulma/sass/utilities/_all";

@import "../../node_modules/bulma/bulma";
@import "_navbar.scss";
@import "_hero.scss";
@import "_content.scss";
@import "_homepage.scss";
@import "_footer.scss";
@import "_sidenav.scss";
@import "_querylist.scss";
@import "_sectionbox.scss";
@import "_toctree.scss";