{% extends "layout.html" %}
{% block hero_image %}
    {% if resource.props.hero_image %}
        background-image: linear-gradient(rgba(0, 0, 0, 0.9), rgba(0, 0, 0,
        0.4)),
        url('/_static/{{ resource.props.hero_image }}');
    {% endif %}
{% endblock %}
{% block hero %}
    <div class="hero-body">
        <div class="container">
            <div class="columns is-vcentered">
                <div class="column">
                    <p class="title">
                        {{ resource.props.heading }}
                    </p>
                    <p class="subtitle">
                        {{ resource.props.subheading }}
                    </p>
                </div>
            </div>
        </div>
    </div>
{% endblock %}
{% block body %}
    {{ body }}
{% endblock %}
