<iframe
        class="kbb-videoplayer"
        width="{{ widget.props.width }}"
        height="{{ widget.props.height }}"
        src="{{ widget.props.src }}"
        frameborder="{{ widget.props.frameborder }}"
        {{ 'allowfullscreen' if widget.props.allowfullscreen }}>&nbsp;
</iframe>
