{% extends "layout.html" %}
{% block body %}
    <div class="container">
        <div class="columns">
            <div class="column sb_body">
                <h1 class="title is-1">{{ page.title }}</h1>
                <div id="kbb-sphinx-body">{{ body }}</div>
            </div>

            <div class="column is-3">
            </div>
        </div>
    </div>
{% endblock %}