@import "../../node_modules/bulma/sass/utilities/derived-variables";

section.section.content.homepage {
  // Bulma has a nice "section" treatment, full width, with hero styling
  // of background color. Sphinx interferes with this by wrapping the
  // RST-generated body in <section class="section content">. Let's disable
  // the effects of this, just for the homepage.
  padding: 0;

  p:not(.panel-heading) {
    //margin: -1rem 10% 2rem 10%;
  }

  .splash .kbb-sectionbox-content {
    font-size: $size-4;
    margin: 1rem 10% 2rem 10%;
  }

  .kbb-sectionbox-content {
    font-size: $size-4;
    a {
      text-decoration: underline;
    }
    a:hover {
      text-decoration: dashed;
    }
  }

}

