@import "../../node_modules/bulma/sass/utilities/derived-variables";

.kbb-querylist nav.panel {
  p.panel-heading {
    margin-bottom: 0;
  }
}

@each $section-color, $pair in $colors {
  $sc: nth($pair, 1);
  $sc-invert: nth($pair, 2);
  .kbb-portlet-#{$section-color} {
    .panel-heading {
      background-color: $sc;
      color: $sc-invert;
    }
  }
}
