<div class="row kbb-querylist">
    <div class="columns">
        {% for result_set in result_sets %}
            <div class="column">
                <nav class="panel kbb-portlet-{{ result_set.style }}">
                    <p class="panel-heading">
                        {{ result_set.label }}
                    </p>
                    {% for result in result_set.results %}
                        <a class="panel-block"
                           href="{{ widget.pathto_docname(result.docname) + '.html' }}">
                            <span class="panel-icon">
                              <i class="fas fa-book"></i>
                            </span>
                            {{ result.title }}
                        </a>
                    {% endfor %}
                </nav>
            </div>
        {% endfor %}
    </div>
</div>
