@import "../../node_modules/bulma/sass/utilities/initial-variables";
@import "../../node_modules/bulma/sass/utilities/derived-variables";

.kbb-listing {
  margin-top: 1.5rem;

  .kbb-listing-title a {
    color: $link;
  }

  .kbb-listing-heading {
    border-bottom: 1px solid gray;
  }

  .kbb-listing-item {
    padding: 1rem;
  }

  .kbb-listing-excerpt {
    font-weight: lighter;
  }

  .kbb-listing-timeago {
    width: 9rem;
    text-align: right;
  }

  .kbb-listing-table {
    tr {
      height: 5rem;

      td {
        border: none;
      }
    }
  }

  .kbb-listing-active {
    background-color: $white-ter;
  }
}