@import "../../node_modules/bulma/sass/utilities/derived-variables";

footer.footer {
  padding: 3rem 1.5rem 3rem;
}

footer.footer {
  @each $section-color, $pair in $colors {
    $sc: nth($pair, 1);
    $sc-invert: nth($pair, 2);
    &.is-#{$section-color} {
      background-color: $sc;
      color: $sc-invert;
      a {
        color: $sc-invert;
        text-decoration: underline;
      }
      a:hover {
        text-decoration: dashed white;
      }
    }
  }
}
