@import "../../node_modules/bulma/sass/utilities/derived-variables";

// Let's use this for styles that apply to everything on the site

#kbb-sphinx-body > div.section > h1:first-child {
  // Sphinx inserts the page title in a way that we'd like to control,
  // so let's hide it. This is tricky to get just the one we want.
  display: none;
}

.section .section {
  // Sphinx generates "section" class which matches Bulma which
  // adds a bunch of extra space.
  padding: 0.75rem 0;
}
